summaryrefslogtreecommitdiffstats
path: root/ktalkd/kcmktalkd/answmachpage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ktalkd/kcmktalkd/answmachpage.cpp')
-rw-r--r--ktalkd/kcmktalkd/answmachpage.cpp56
1 files changed, 28 insertions, 28 deletions
diff --git a/ktalkd/kcmktalkd/answmachpage.cpp b/ktalkd/kcmktalkd/answmachpage.cpp
index c0aec185..3f426821 100644
--- a/ktalkd/kcmktalkd/answmachpage.cpp
+++ b/ktalkd/kcmktalkd/answmachpage.cpp
@@ -29,7 +29,7 @@
#include <stdlib.h>
#include <klocale.h> // for getenv
-KAnswmachPageConfig::KAnswmachPageConfig( QWidget *parent, const char* name,
+KAnswmachPageConfig::KAnswmachPageConfig( TQWidget *parent, const char* name,
KSimpleConfig *_config)
: KCModule (parent, name)
{
@@ -42,42 +42,42 @@ KAnswmachPageConfig::KAnswmachPageConfig( QWidget *parent, const char* name,
config = _config;
}
- answmach_cb = new QCheckBox(i18n("&Activate answering machine"), this);
+ answmach_cb = new TQCheckBox(i18n("&Activate answering machine"), this);
answmach_cb->adjustSize();
- mail_edit = new QLineEdit(this);
+ mail_edit = new TQLineEdit(this);
mail_edit->adjustSize();
mail_edit->setMinimumWidth(150);
- mail_label = new QLabel(mail_edit,i18n("&Mail address:"),this);
+ mail_label = new TQLabel(mail_edit,i18n("&Mail address:"),this);
mail_label->adjustSize();
mail_label->setAlignment( ShowPrefix | AlignVCenter );
- subj_edit = new QLineEdit(this);
+ subj_edit = new TQLineEdit(this);
subj_edit->adjustSize();
subj_edit->setMinimumWidth(150);
- subj_label = new QLabel(subj_edit, i18n("Mail s&ubject:"),this);
+ subj_label = new TQLabel(subj_edit, i18n("Mail s&ubject:"),this);
subj_label->adjustSize();
subj_label->setAlignment( ShowPrefix | AlignVCenter );
- subj_tip = new QLabel(i18n("Use %s for the caller name"),this);
+ subj_tip = new TQLabel(i18n("Use %s for the caller name"),this);
subj_tip->setAlignment( ShowPrefix );
- head_edit = new QLineEdit(this);
+ head_edit = new TQLineEdit(this);
head_edit->adjustSize();
head_edit->setMinimumWidth(150);
- head_label = new QLabel(head_edit, i18n("Mail &first line:"),this);
+ head_label = new TQLabel(head_edit, i18n("Mail &first line:"),this);
head_label->adjustSize();
head_label->setAlignment( ShowPrefix | AlignVCenter );
- head_tip = new QLabel(
+ head_tip = new TQLabel(
i18n("Use first %s for caller name, and second %s for caller hostname"),
this);
head_tip->setAlignment( ShowPrefix );
- emptymail_cb = new QCheckBox(i18n("&Receive a mail even if no message left"), this);
+ emptymail_cb = new TQCheckBox(i18n("&Receive a mail even if no message left"), this);
emptymail_cb->adjustSize();
- msg_ml = new QMultiLineEdit(this);
+ msg_ml = new TQMultiLineEdit(this);
msg_ml->adjustSize();
msg_ml->setMinimumWidth(150);
- msg_label = new QLabel(msg_ml, i18n("&Banner displayed on answering machine startup:"),this);
+ msg_label = new TQLabel(msg_ml, i18n("&Banner displayed on answering machine startup:"),this);
msg_label->adjustSize();
msg_label->setAlignment( ShowPrefix | AlignVCenter );
@@ -86,24 +86,24 @@ KAnswmachPageConfig::KAnswmachPageConfig( QWidget *parent, const char* name,
+ head_tip->height() + emptymail_cb->height() +
msg_label->height() + msg_ml->height() + 30;
setMinimumSize(400, h); // 400 : otherwise, buttons may overlap
- msg_default = new QString(i18n("The person you are asking to talk with is not answering.\n"
+ msg_default = new TQString(i18n("The person you are asking to talk with is not answering.\n"
"Please leave a message to be delivered via email.\n"
"Just start typing and when you have finished, exit normally."));
load();
- connect(answmach_cb, SIGNAL(clicked()), this, SLOT(answmachOnOff()));
+ connect(answmach_cb, TQT_SIGNAL(clicked()), this, TQT_SLOT(answmachOnOff()));
// Emit changed(true) when anything changes
- connect(answmach_cb, SIGNAL(clicked()), this, SLOT(slotChanged()));
- connect(mail_edit, SIGNAL(textChanged(const QString&)),
- this, SLOT(slotChanged()));
- connect(subj_edit, SIGNAL(textChanged(const QString&)),
- this, SLOT(slotChanged()));
- connect(head_edit, SIGNAL(textChanged(const QString&)),
- this, SLOT(slotChanged()));
- connect(emptymail_cb, SIGNAL(clicked()), this, SLOT(slotChanged()));
- connect(msg_ml, SIGNAL(textChanged()), this, SLOT(slotChanged()));
+ connect(answmach_cb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotChanged()));
+ connect(mail_edit, TQT_SIGNAL(textChanged(const TQString&)),
+ this, TQT_SLOT(slotChanged()));
+ connect(subj_edit, TQT_SIGNAL(textChanged(const TQString&)),
+ this, TQT_SLOT(slotChanged()));
+ connect(head_edit, TQT_SIGNAL(textChanged(const TQString&)),
+ this, TQT_SLOT(slotChanged()));
+ connect(emptymail_cb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotChanged()));
+ connect(msg_ml, TQT_SIGNAL(textChanged()), this, TQT_SLOT(slotChanged()));
}
@@ -128,10 +128,10 @@ void KAnswmachPageConfig::slotChanged() {
emit changed(true);
}
-void KAnswmachPageConfig::resizeEvent(QResizeEvent *) {
+void KAnswmachPageConfig::resizeEvent(TQResizeEvent *) {
int h_txt = answmach_cb->height(); // taken for the general label height
- int h_edt = mail_edit->height(); // taken for the general QLineEdit height
+ int h_edt = mail_edit->height(); // taken for the general TQLineEdit height
int spc = h_txt / 3;
int w = rect().width();
@@ -223,7 +223,7 @@ void KAnswmachPageConfig::load() {
msg_ml->clear();
char m[]="Msg1"; // used as key to read configuration
- QString msg;
+ TQString msg;
while (!(msg=config->readEntry(m)).isNull())
{
msg_ml->append(msg);
@@ -249,7 +249,7 @@ void KAnswmachPageConfig::save() {
config->writeEntry("EmptyMail", emptymail_cb->isChecked());
char m[]="Msg1"; // used as key to read configuration
int linenr=0;
- QString msg;
+ TQString msg;
while ((linenr<8) && (linenr<msg_ml->numLines()))
{
config->writeEntry(m,msg_ml->textLine(linenr));